@@ -23,17 +23,18 @@ package kernel
 
 import (
 	"encoding/json"
-	"errors"
 	"fmt"
-	"maps"
 	"os"
 	"path/filepath"
+	"regexp"
 	"strings"
 
 	"github.com/apex/log"
 	"github.com/blacktop/go-macho"
+	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/signature"
 	"github.com/fatih/color"
+	"github.com/invopop/jsonschema"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -46,6 +47,8 @@ func init() {
 	kernelSymbolicateCmd.Flags().BoolP("quiet", "q", false, "Don't display logging")
 	kernelSymbolicateCmd.Flags().Bool("test", false, "Test symbol matches")
 	kernelSymbolicateCmd.Flags().MarkHidden("test")
+	kernelSymbolicateCmd.Flags().Bool("schema", false, "Generate JSON schema")
+	kernelSymbolicateCmd.Flags().MarkHidden("schema")
 	kernelSymbolicateCmd.Flags().StringP("signatures", "s", "", "Path to signatures folder")
 	kernelSymbolicateCmd.MarkFlagRequired("signatures")
 	kernelSymbolicateCmd.Flags().StringP("output", "o", "", "Folder to write files to")
@@ -54,6 +57,7 @@ func init() {
 	viper.BindPFlag("kernel.symbolicate.json", kernelSymbolicateCmd.Flags().Lookup("json"))
 	viper.BindPFlag("kernel.symbolicate.quiet", kernelSymbolicateCmd.Flags().Lookup("quiet"))
 	viper.BindPFlag("kernel.symbolicate.test", kernelSymbolicateCmd.Flags().Lookup("test"))
+	viper.BindPFlag("kernel.symbolicate.schema", kernelSymbolicateCmd.Flags().Lookup("schema"))
 	viper.BindPFlag("kernel.symbolicate.signatures", kernelSymbolicateCmd.Flags().Lookup("signatures"))
 	viper.BindPFlag("kernel.symbolicate.output", kernelSymbolicateCmd.Flags().Lookup("output"))
 }
@@ -81,33 +85,39 @@ var kernelSymbolicateCmd = &cobra.Command{
 			output = filepath.Dir(filepath.Clean(args[0]))
 		}
 
+		if viper.GetBool("kernel.symbolicate.schema") {
+			schema := jsonschema.Reflect(&signature.Symbolicator{})
+			schema.Description = "ipsw Symbolicator definition file"
+			bts, err := json.MarshalIndent(schema, "	", "	")
+			if err != nil {
+				return fmt.Errorf("failed to create jsonschema: %w", err)
+			}
+			if viper.IsSet("kernel.symbolicate.output") {
+				if viper.GetString("kernel.symbolicate.output") == "-" {
+					fmt.Println(string(bts))
+					return nil
+				}
+				schemaFile := filepath.Join(output, "symbolicator.schema.json")
+				log.Infof("Writing JSON schema to %s", schemaFile)
+				return os.WriteFile(schemaFile, bts, 0o644)
+			}
+		}
+
 		log.Info("Parsing Signatures")
 		sigs, err := signature.Parse(viper.GetString("kernel.symbolicate.signatures"))
 		if err != nil {
 			return fmt.Errorf("failed to parse signatures: %v", err)
 		}
 
+		smap := signature.NewSymbolMap()
+
 		// symbolicate kernelcache
-		symMap := make(map[uint64]string)
-		goodsig := false
 		log.WithField("kernelcache", filepath.Base(args[0])).Info("Symbolicating...")
-		for _, sig := range sigs {
-			syms, err := signature.Symbolicate(args[0], sig, quiet)
-			if err != nil {
-				if errors.Is(err, signature.ErrUnsupportedTarget) ||
-					errors.Is(err, signature.ErrUnsupportedVersion) {
-					continue
-				}
-				return fmt.Errorf("failed to symbolicate kernelcache: %v", err)
-			}
-			maps.Copy(symMap, syms)
-			goodsig = true
-		}
-
-		if !goodsig {
-			return fmt.Errorf("no valid signatures found for kernelcache (let author know and we can add them)")
+		if err := smap.Symbolicate(args[0], sigs, quiet); err != nil {
+			return fmt.Errorf("failed to symbolicate kernelcache: %v", err)
 		}
 
+		// test the accuracy of the symbolication on the source KDK material
 		if viper.GetBool("kernel.symbolicate.test") {
 			match := 0
 			miss := 0
@@ -117,34 +127,51 @@ var kernelSymbolicateCmd = &cobra.Command{
 				return fmt.Errorf("failed to open kernelcache: %v", err)
 			}
 			defer m.Close()
-			for addr, sym := range symMap {
+			for addr, sym := range smap {
 				syms, err := m.FindAddressSymbols(addr)
 				if err != nil {
 					log.WithError(err).Errorf("symbol '%s' with addr %#x not found in kernelcache", sym, addr)
 					continue
 				}
+				matched := false
 				for _, s := range syms {
-					log.Debug(s.String(m))
-					if before, ok := strings.CutSuffix(s.Name, sym); ok {
-						if before != "_" && before != "" {
-							log.Warnf("Unexpected symbol prefix: %s", before)
+					s.Name = regexp.MustCompile(`\.\d+$`).ReplaceAllString(s.Name, "")
+					s.Name = strings.TrimPrefix(s.Name, "__kernelrpc")
+					switch {
+					case strings.TrimLeft(sym, "_") == strings.TrimLeft(s.Name, "_"):
+						fallthrough
+					case strings.TrimSuffix(sym, "_trap") == strings.TrimLeft(s.Name, "_"):
+						matched = true
+						if !quiet {
+							log.Infof("✅ Symbol '%s' matches", sym)
 						}
-						log.Infof("✅ Symbol '%s' matches", sym)
-						match++
-					} else {
-						log.Errorf("❌ Symbol at address %#x mismatch: matched %s, actual %s", addr, sym, s.Name)
-						miss++
+					default:
+						// log.Debug(s.String(m))
 					}
 				}
+				if matched {
+					match++
+				} else {
+					var ss []string
+					for _, s := range syms {
+						ss = append(ss, s.Name)
+					}
+					utils.Indent(log.Error, 2)(
+						fmt.Sprintf("❌ Symbol at address %#x mismatch: matched %s, actual %s", addr, sym, strings.Join(ss, ", ")),
+					)
+					miss++
+				}
 			}
-			log.Infof("Matched %d symbols, missed %d symbols", match, miss)
+			utils.Indent(log.Info, 2)(
+				fmt.Sprintf("Matched %d symbols, Missed %d symbols: %.4f%%", match, miss, 100*float64(match)/float64(len(smap))),
+			)
 			return nil
 		}
 
 		/* JSON OUTPUT */
 
 		if viper.GetBool("kernel.symbolicate.json") {
-			jdat, err := json.Marshal(symMap)
+			jdat, err := json.Marshal(smap)
 			if err != nil {
 				return fmt.Errorf("failed to marshal symbol map: %v", err)
 			}
@@ -163,14 +190,14 @@ var kernelSymbolicateCmd = &cobra.Command{
 				return fmt.Errorf("failed to create symbols file: %v", err)
 			}
 			defer f.Close()
-			for addr, sym := range symMap {
+			for addr, sym := range smap {
 				fmt.Fprintf(f, "%#x %s\n", addr, sym)
 			}
 			return nil
 		}
 
 		fmt.Printf("%s symbols:\n", filepath.Base(args[0]))
-		for addr, sym := range symMap {
+		for addr, sym := range smap {
 			fmt.Printf("%#x %s\n", addr, sym)
 		}
 
