@@ -267,8 +267,11 @@ func (d *Diff) Markdown() error {
 	}
 
 	// SECTION: DSC
-	out.WriteString("## DSC\n\n")
-	if len(d.Old.Webkit) > 0 {
+	if len(d.Old.Webkit) > 0 && len(d.New.Webkit) > 0 &&
+		d.Dylibs != nil && (len(d.Dylibs.New) > 0 || len(d.Dylibs.Removed) > 0 || len(d.Dylibs.Updated) > 0) {
+		out.WriteString("## DSC\n\n")
+	}
+	if len(d.Old.Webkit) > 0 && len(d.New.Webkit) > 0 {
 		out.WriteString(
 			fmt.Sprintf(
 				"### WebKit\n\n"+
