@@ -779,7 +779,7 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 			}
 		}()
 		for k := range out {
-			kextSyms := make(map[string]map[uint64]string)
+			smap := signature.NewSymbolMap()
 			if i.Config.SignaturesDir != "" {
 				// parse signatures
 				sigs, err := signature.Parse(i.Config.SignaturesDir)
@@ -788,18 +788,9 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 				}
 				// symbolicate kernelcache
 				log.WithField("kernelcache", filepath.Base(k)).Info("Symbolicating...")
-				for _, sig := range sigs {
-					syms, err := signature.Symbolicate(k, sig, true)
-					if err != nil {
-						if errors.Is(err, signature.ErrUnsupportedVersion) {
-							continue
-						}
-						return fmt.Errorf("failed to symbolicate kernelcache: %v", err)
-					}
-					kextSyms[sig.Target] = make(map[uint64]string)
-					kextSyms[sig.Target] = syms
+				if err := smap.Symbolicate(k, sigs, true); err != nil {
+					return fmt.Errorf("failed to symbolicate kernelcache: %v", err)
 				}
-				log.WithField("kernelcache", filepath.Base(k)).Warn("No signatures found for kernelcache")
 			}
 
 			kc, err := macho.Open(k)
@@ -820,10 +811,8 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 								fn.Name = sym.Name
 							}
 						} else {
-							if syms, ok := kextSyms[fe.EntryID]; ok {
-								if sym, ok := syms[fn.StartAddr]; ok {
-									fn.Name = sym
-								}
+							if sym, ok := smap[fn.StartAddr]; ok {
+								fn.Name = sym
 							}
 						}
 						if fn.Name == "" {
@@ -839,10 +828,8 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 							fn.Name = sym.Name
 						}
 					} else {
-						for _, syms := range kextSyms {
-							if sym, ok := syms[fn.StartAddr]; ok {
-								fn.Name = sym
-							}
+						if sym, ok := smap[fn.StartAddr]; ok {
+							fn.Name = sym
 						}
 						if fn.Name == "" {
 							fn.Name = fmt.Sprintf("func_%x", fn.StartAddr)
